window.Gleam.initSearch([{"doc":"glibsql","title":"glibsql","content":"# glibsql\n\n[![Package Version](https://img.shields.io/hexpm/v/glibsql)](https://hex.pm/packages/glibsql)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glibsql/)\n\nGlibsql is a library for interacting with a hosted libSQL database such as [Turso](https://turso.tech).\n\n## glibsql/http\n\n`glibsql/http` helps construct a `gleam/http/request` for use with the [Hrana over HTTP](https://docs.turso.tech/sdk/http/reference) variant of libSQL,\nsimply pass the constructed HTTP request into your http client of choice.\n\n```sh\ngleam add glibsql\n```\n```gleam\nimport gleam/httpc\nimport gleam/result\nimport glibsql/http as glibsql\n\npub fn main() {\n  // The first request does not have to include a `CloseStatement`,\n  // a baton is returned from the first request to be used in subsequent requests.\n  let request =\n    base_request()\n    |&gt; glibsql.with_statement(glibsql.ExecuteStatement(\n      sql: &quot;BEGIN&quot;,\n    ))\n    |&gt; glibsql.with_statement(glibsql.ExecuteStatement(\n      sql: &quot;SELECT * FROM users&quot;,\n    ))\n    |&gt; glibsql.build\n\n  let assert Ok(request) = request\n\n  use response &lt;- result.try(httpc.send(request))\n\n  // ...\n\n  // The second request uses the baton from the first request to reuse the connection.\n  // This is useful if you are making multiple requests to the same database, especially\n  // within a transaction.\n  let second_request =\n    base_request()\n    |&gt; glibsql.with_statement(glibsql.ExecuteStatement(\n      sql: &quot;UPDATE posts SET status = &#39;published&#39; WHERE user_id IN (1,2,3)&quot;,\n    ))\n    |&gt; glibsql.with_statement(glibsql.ExecuteStatement(\n      sql: &quot;COMMIT&quot;,\n    ))\n    |&gt; glibsql.with_statement(glibsql.CloseStatement)\n    |&gt; glibsql.with_baton(&quot;&lt;baton from previous request&gt;&quot;)\n    |&gt; glibsql.build\n\n  let assert Ok(second_request) = second_request\n\n  use response &lt;- result.try(httpc.send(second_request))\n}\n\nfn base_request() {\n  glibsql.new_request()\n  |&gt; glibsql.with_database(&quot;database&quot;)\n  |&gt; glibsql.with_organization(&quot;organization&quot;)\n  |&gt; glibsql.with_token(&quot;token&quot;)\n}\n\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glibsql&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"glibsql/libsql","title":"Config","content":"pub opaque type Config\n Config encapsulates everything needed to construct a libSQL client.\n\n see `new_client()` to construct this record.\n\nSynonyms:\nglibsql/libsql.Config\nglibsql/libsql Config","url":"glibsql/libsql.html#Config"},{"doc":"glibsql/libsql","title":"GlibsqlError","content":"pub opaque type GlibsqlError\n Error type for all possible errors returned by glibsql/http.\n\nSynonyms:\nglibsql/libsql.GlibsqlError\nglibsql/libsql GlibsqlError","url":"glibsql/libsql.html#GlibsqlError"},{"doc":"glibsql/libsql","title":"LibsqlClient","content":"pub type LibsqlClient\n LibsqlClient encapsulates everything needed to interact with a libSQL server.\n\n see `build()` to construct this record.\n\nSynonyms:\nglibsql/libsql.LibsqlClient\nglibsql/libsql LibsqlClient","url":"glibsql/libsql.html#LibsqlClient"},{"doc":"glibsql/libsql","title":"LibsqlResponse","content":"pub opaque type LibsqlResponse(records)\n Represents a response from a libSQL query.\n\n The `records` parameter is the type of the rows returned by the query.\n\nSynonyms:\nglibsql/libsql.LibsqlResponse\nglibsql/libsql LibsqlResponse","url":"glibsql/libsql.html#LibsqlResponse"},{"doc":"glibsql/libsql","title":"build","content":"pub fn build(\n  config: Config,\n) -&gt; Result(LibsqlClient, GlibsqlError)\n Build the libSQL client using the previously provided values.\nSynonyms:\nglibsql/libsql.build\nglibsql/libsql build","url":"glibsql/libsql.html#build"},{"doc":"glibsql/libsql","title":"execute","content":"pub fn execute(\n  query: String,\n  on client: LibsqlClient,\n  returning decoder: Decoder(a),\n) -&gt; Promise(Result(LibsqlResponse(a), GlibsqlError))\n Execute a query against the database.\n\n Returns a `LibsqlResponse` containing\n - the number of rows affected\n - the last insert rowid\n - the rows returned by the query (decoded using the provided decoder)\nSynonyms:\nglibsql/libsql.execute\nglibsql/libsql execute","url":"glibsql/libsql.html#execute"},{"doc":"glibsql/libsql","title":"new_client","content":"pub fn new_client() -&gt; Config\n Create a new libSQL client.\n\n Uses the builder pattern to construct everything necessary to start a client.\nSynonyms:\nglibsql/libsql.new_client\nglibsql/libsql new_client","url":"glibsql/libsql.html#new_client"},{"doc":"glibsql/libsql","title":"with_token","content":"pub fn with_token(client: Config, token: String) -&gt; Config\n Set the Bearer token to access the database. Do not include `Bearer `.\n Calling this function multiple times will override the previous value.\nSynonyms:\nglibsql/libsql.with_token\nglibsql/libsql with_token","url":"glibsql/libsql.html#with_token"},{"doc":"glibsql/libsql","title":"with_url","content":"pub fn with_url(client: Config, url: String) -&gt; Config\n Set the target database URL.\n Calling this function multiple times will override the previous value.\nSynonyms:\nglibsql/libsql.with_url\nglibsql/libsql with_url","url":"glibsql/libsql.html#with_url"},{"doc":"glibsql/libsql","title":"glibsql/libsql","content":" glibsql/libsql helps construct and eexecute a libSQL request.","url":"glibsql/libsql.html"},{"doc":"glibsql","title":"main","content":"pub fn main() -&gt; Promise(Result(Nil, a))\n\nSynonyms:\nglibsql.main\nglibsql main","url":"glibsql.html#main"},{"doc":"glibsql","title":"glibsql","content":"","url":"glibsql.html"},{"doc":"glibsql/http","title":"GlibsqlError","content":"pub opaque type GlibsqlError\n Error type for all possible errors returned by glibsql/http.\n\nSynonyms:\nglibsql/http.GlibsqlError\nglibsql/http GlibsqlError","url":"glibsql/http.html#GlibsqlError"},{"doc":"glibsql/http","title":"HttpRequest","content":"pub opaque type HttpRequest\n HttpRequest encapsulates everything needed to execute\n a Hrana over HTTP libSQL request.\n\n see `new_request()` to construct this record.\n\nSynonyms:\nglibsql/http.HttpRequest\nglibsql/http HttpRequest","url":"glibsql/http.html#HttpRequest"},{"doc":"glibsql/http","title":"Statement","content":"pub type Statement {\n  ExecuteStatement(sql: String)\n  CloseStatement\n}\n Statement wraps the supported types of requests.\n A series of `ExecuteStatement(String)`s can be applied and\n be conditionally followed with a `CloseStatement` to close\n a connection when you are done with it.\nExecuteStatement(sql: String)\n `ExecuteStatement` contains a query that will be executed as written.\n There is no SQL-injection protection provided, this type of statement\n should be used with a query builder that can render the built query\n to a prepared string.\n\nCloseStatement\n `CloseStatment` will either close the connection used in the current \n pipeline or will close the connection referenced by the request baton.\n Note: connections will be automatically closed by Turso after a 10s timeout.\n\nSynonyms:\nglibsql/http.Statement\nglibsql/http Statement","url":"glibsql/http.html#Statement"},{"doc":"glibsql/http","title":"build","content":"pub fn build(\n  request: HttpRequest,\n) -&gt; Result(Request(String), GlibsqlError)\n Build the request using the previously provided values.\n Returns a gleam/http request suitable to be used in your HTTP client of choice.\nSynonyms:\nglibsql/http.build\nglibsql/http build","url":"glibsql/http.html#build"},{"doc":"glibsql/http","title":"clear_statements","content":"pub fn clear_statements(request: HttpRequest) -&gt; HttpRequest\n Clear all statements from the request.\nSynonyms:\nglibsql/http.clear_statements\nglibsql/http clear_statements","url":"glibsql/http.html#clear_statements"},{"doc":"glibsql/http","title":"new_request","content":"pub fn new_request() -&gt; HttpRequest\n Create a new Hrana over HTTP libSQL request.\n\n Uses the builder pattern to construct everything necessary to send a request.\nSynonyms:\nglibsql/http.new_request\nglibsql/http new_request","url":"glibsql/http.html#new_request"},{"doc":"glibsql/http","title":"with_baton","content":"pub fn with_baton(\n  request: HttpRequest,\n  baton: String,\n) -&gt; HttpRequest\n Set the baton from a previous connection to be reused.\nSynonyms:\nglibsql/http.with_baton\nglibsql/http with_baton","url":"glibsql/http.html#with_baton"},{"doc":"glibsql/http","title":"with_database","content":"pub fn with_database(\n  request: HttpRequest,\n  database: String,\n) -&gt; HttpRequest\n Set the target database name.\n Calling this function multiple times will override the previous value.\n\n Given a Turso databse URL like libsql://example-database-myorganization.turso.io\n The database name is &quot;example-database&quot;\nSynonyms:\nglibsql/http.with_database\nglibsql/http with_database","url":"glibsql/http.html#with_database"},{"doc":"glibsql/http","title":"with_host","content":"pub fn with_host(\n  request: HttpRequest,\n  host: String,\n) -&gt; HttpRequest\n Set the target database host.\n NOTE: this defaults to Turso&#39;s turso.io\n Calling this function multiple times will override the previous value.\n\n Given a Turso databse URL like libsql://example-database-myorganization.turso.io\n The host name is &quot;turso.io&quot;\nSynonyms:\nglibsql/http.with_host\nglibsql/http with_host","url":"glibsql/http.html#with_host"},{"doc":"glibsql/http","title":"with_organization","content":"pub fn with_organization(\n  request: HttpRequest,\n  organization: String,\n) -&gt; HttpRequest\n Set the target database organization.\n Calling this function multiple times will override the previous value.\n\n Given a Turso databse URL like libsql://example-database-myorganization.turso.io\n The database name is &quot;myorganization&quot;\nSynonyms:\nglibsql/http.with_organization\nglibsql/http with_organization","url":"glibsql/http.html#with_organization"},{"doc":"glibsql/http","title":"with_path","content":"pub fn with_path(\n  request: HttpRequest,\n  path: String,\n) -&gt; HttpRequest\n Set the target database path on the host.\n NOTE: this defaults to Turso&#39;s /v2/pipeline\n Calling this function multiple times will override the previous value.\nSynonyms:\nglibsql/http.with_path\nglibsql/http with_path","url":"glibsql/http.html#with_path"},{"doc":"glibsql/http","title":"with_statement","content":"pub fn with_statement(\n  request: HttpRequest,\n  statement: Statement,\n) -&gt; HttpRequest\n Set a statement on the request.\n This function may be called multiple times, additional statements will be\n executed in order.\nSynonyms:\nglibsql/http.with_statement\nglibsql/http with_statement","url":"glibsql/http.html#with_statement"},{"doc":"glibsql/http","title":"with_token","content":"pub fn with_token(\n  request: HttpRequest,\n  token: String,\n) -&gt; HttpRequest\n Set the Bearer token to access the database. Do not include `Bearer `.\n Calling this function multiple times will override the previous value.\nSynonyms:\nglibsql/http.with_token\nglibsql/http with_token","url":"glibsql/http.html#with_token"},{"doc":"glibsql/http","title":"glibsql/http","content":" glibsql/http helps construct a `gleam/http/request` for use with the [Hrana over HTTP](https://docs.turso.tech/sdk/http/reference) variant of libSQL,\n simply pass the constructed HTTP request into your http client of choice.","url":"glibsql/http.html"}]);